<?php

/**
 * Created by PhpStorm.
 * User: chaas
 * Date: 18.03.15
 * Time: 17:33.
 */

namespace OCSAPI\Exception;

class FileNotFoundException extends \Exception {}
